# Terminal

### Optional arguments:

```shell
  -v, --version       Get version of Bomiot
  -h, --help          Show this help message and exit
```

### Available commands:

```shell
    new               Create APP for project
    project           Project workspace, default to bomiot
    plugins           Plugins workspace, default to bomiot
    deploy            Deploy project
    init              Init bomiot
    initadmin         Create default super user admin
    initpwd           Init admin password
    migrate           Migrate database
    makemigrations    Generate migrations for database
    loaddata          Load data from configs
    dumpdata          Dump data to configs
    market            Copy project from marketplace
    keys              Init auth keys
    run               Run server
```